###v1.1.0
- fixed parsing instances where a title isn't found
- now saved links to each movie on TMDb and checks so subsequent searches
don't re-find each match, and so you can specify the correct link
- fixed issue where choices made weren't processed
- retitling movies now follows more common-place rules, such as not 
capitalizing coordinating conjunctions unless they start or end the title
- fixed issue where index.htm may not be updated even if new information is downloaded
on a new run.
- added force_specific feature to config file
- fixed an issue with how movies are generated if the ID is known
- lots of small bug fixes

###v1.0.0
- Released 1.0